@@ -12,6 +12,7 @@ import json
 import sys
 import time
 import uuid
+from collections.abc import Collection
 
 import confluent_kafka
 
@@ -107,12 +108,15 @@ class AllConsumingConsumer:
         self,
         broker,
         timeout=None,
-        topics=["^ztf_.*"],
+        topics=("^ztf_.*",),
         auto_commit=True,
-        logger: None | LoggerProtocol=None,
+        logger: None | LoggerProtocol = None,
         **consumer_config,
     ):
-        """ """
+        """
+        :param auto_commit: implicitly store the offset of the last emitted
+            message on the next call to consume()
+        """
 
         self._metrics = KafkaMetrics.instance()
         config = {
@@ -133,7 +137,7 @@ class AllConsumingConsumer:
         self._consumer = confluent_kafka.Consumer(**config)
         self._logger = logger
 
-        self._consumer.subscribe(topics)
+        self._consumer.subscribe(list(topics))
         if timeout is None:
             self._poll_interval = 1
             self._poll_attempts = sys.maxsize
@@ -142,19 +146,37 @@ class AllConsumingConsumer:
             self._poll_attempts = max((1, int(timeout / self._poll_interval)))
         self._timeout = timeout
 
-        self._offsets: dict[tuple[str,int],int] = {}
+        self._offsets: dict[tuple[str, int], int] = {}
         self._auto_commit = auto_commit
 
     def __next__(self):
         message = self.consume()
         if message is None:
             raise StopIteration
-        else:
-            return message
+        return message
 
     def __iter__(self):
         return self
 
+    def store_offsets(
+        self,
+        offsets: Collection[confluent_kafka.TopicPartition],
+    ):
+        if self._logger:
+            self._logger.debug(f"Storing offsets: {offsets}")
+        try:
+            self._consumer.store_offsets(offsets=offsets)
+        except confluent_kafka.KafkaException as exc:
+            # librdkafka will refuse to store offsets on a partition that is not
+            # currently assigned. this can happen if the group is rebalanced
+            # while a batch of messages is in flight. see also:
+            # https://github.com/confluentinc/confluent-kafka-dotnet/issues/1861
+            err = exc.args[0]
+            if err.code() == confluent_kafka.KafkaError._STATE:  # noqa: SLF001
+                ...
+            else:
+                raise KafkaError(err) from exc
+
     def commit(self):
         if self._offsets:
             offsets = [
@@ -167,9 +189,13 @@ class AllConsumingConsumer:
                 self._consumer.store_offsets(offsets=offsets)
                 self._offsets.clear()
             else:
-                for toppar in self._consumer.commit(offsets=offsets, asynchronous=False):
+                for toppar in self._consumer.commit(
+                    offsets=offsets, asynchronous=False
+                ):
                     if toppar.error:
-                        self._logger.error(f"Commit {toppar} failed with {toppar.error}")
+                        self._logger.error(
+                            f"Commit {toppar} failed with {toppar.error}"
+                        )
                     else:
                         del self._offsets[(toppar.topic, toppar.partition)]
 
@@ -182,7 +208,13 @@ class AllConsumingConsumer:
         """
         # mark the last emitted message for committal
         if self._auto_commit:
-            self.commit()
+            self.store_offsets(
+                [
+                    confluent_kafka.TopicPartition(topic, partition, offset + 1)
+                    for (topic, partition), offset in self._offsets.items()
+                ]
+            )
+            self._offsets.clear()
 
         message = None
         for _ in range(self._poll_attempts):
@@ -193,9 +225,9 @@ class AllConsumingConsumer:
                     if err.code() == confluent_kafka.KafkaError.UNKNOWN_TOPIC_OR_PART:
                         # ignore unknown topic messages
                         continue
-                    elif err.code() in (
-                        confluent_kafka.KafkaError._TIMED_OUT,
-                        confluent_kafka.KafkaError._MAX_POLL_EXCEEDED,
+                    if err.code() in (
+                        confluent_kafka.KafkaError._TIMED_OUT,  # noqa: SLF001
+                        confluent_kafka.KafkaError._MAX_POLL_EXCEEDED,  # noqa: SLF001
                     ):
                         # bail on timeouts
                         if self._logger:
@@ -205,9 +237,8 @@ class AllConsumingConsumer:
 
         if message is None:
             return message
-        elif message.error():
+        if message.error():
             raise KafkaError(message.error())
-        else:
-            self._offsets[(message.topic(), message.partition())] = message.offset()
-            self._metrics.on_consume(message)
-            return message
+        self._offsets[(message.topic(), message.partition())] = message.offset()
+        self._metrics.on_consume(message)
+        return message
