@@ -12,9 +12,9 @@ from typing import Any
 
 import backoff
 import requests
+
 from ampel.abstract.AbsAlertLoader import AbsAlertLoader
 from ampel.base.AmpelBaseModel import AmpelBaseModel
-from ampel.struct.Resource import Resource
 
 log = logging.getLogger(__name__)
 
@@ -42,11 +42,7 @@ class ZTFArchiveAlertLoader(AbsAlertLoader):
     archive: str = "https://ampel.zeuthen.desy.de/api/ztf/archive/v3"
 
     #: A stream identifier, created via POST /api/ztf/archive/streams/, or a query
-    stream: None | str | ZTFSource
-
-    #: Name of dynamic resource, fetched by a T3 process and forwarded
-    #: to suppliers/loaders by AlertConsumer via their methods add_resource
-    resource_name: str = "ztf_stream_token"
+    stream: None | str | ZTFSource = "%%ztf_stream_token"
 
     with_history: bool = True
 
@@ -54,16 +50,6 @@ class ZTFArchiveAlertLoader(AbsAlertLoader):
         super().__init__(**kwargs)
         self._it = None
 
-    # override
-    def add_resource(self, name: str, resource: Resource) -> None:
-        if name == self.resource_name:
-            if not isinstance(resource.value, str):
-                raise ValueError(
-                    f"Unexpected {self.resource_name} resource "
-                    f"value type: {type(resource.value)}"
-                )
-            self.stream = resource.value
-
     def __iter__(self):
         return self.get_alerts()
 
