@@ -7,14 +7,16 @@
 # Date:                03.11.2020
 # Last Modified By:    Jakob van Santen <jakob.van.santen@desy.de>
 
-import asyncio, nest_asyncio
-from typing import Any, Tuple
+import asyncio
 from collections.abc import Iterable
+from typing import Any
+
+import nest_asyncio
 
-from ampel.struct.T3Store import T3Store
-from ampel.struct.AmpelBuffer import AmpelBuffer
-from ampel.secret.NamedSecret import NamedSecret
 from ampel.abstract.AbsBufferComplement import AbsBufferComplement
+from ampel.secret.NamedSecret import NamedSecret
+from ampel.struct.AmpelBuffer import AmpelBuffer
+from ampel.struct.T3Store import T3Store
 from ampel.ztf.t3.skyportal.SkyPortalClient import SkyPortalAPIError, SkyPortalClient
 
 
@@ -26,11 +28,9 @@ class FritzReport(SkyPortalClient, AbsBufferComplement):
     #: Base URL of SkyPortal server
     base_url: str = "https://fritz.science"
     #: API token
-    token: NamedSecret[str] = NamedSecret(label="fritz/jno/ampelbot")
+    token: NamedSecret[str] = NamedSecret[str](label="fritz/jno/ampelbot")
 
-    async def get_catalog_item(
-        self, names: tuple[str, ...]
-    ) -> None | dict[str, Any]:
+    async def get_catalog_item(self, names: tuple[str, ...]) -> None | dict[str, Any]:
         """Get catalog entry associated with the stock name"""
         for name in names:
             if name.startswith("ZTF"):
