@@ -6,25 +6,34 @@
 # Last Modified Date:  24.11.2022
 # Last Modified By:    Simeon Reusch <simeon.reusch@desy.de>
 
-import asyncio, base64, gzip, io, json, math, time, aiohttp, backoff
-import numpy as np
-
+import asyncio
+import base64
+import gzip
+import io
+import json
+import math
+import time
 from collections import defaultdict
-from contextlib import asynccontextmanager
-from datetime import datetime
+from collections.abc import Generator, Iterable, Sequence
+from contextlib import asynccontextmanager, suppress
+from datetime import datetime, timezone
+from typing import TYPE_CHECKING, Any, TypedDict, overload
+from urllib.parse import urlparse
+
+import aiohttp
+import backoff
+import numpy as np
 from astropy.io import fits
 from matplotlib.colors import Normalize
 from matplotlib.figure import Figure
-from typing import Any, TypedDict, overload, TYPE_CHECKING
-from collections.abc import Sequence, Generator, Iterable
-from urllib.parse import urlparse
 
+from ampel.base.AmpelBaseModel import AmpelBaseModel
 from ampel.base.AmpelUnit import AmpelUnit
+from ampel.enum.DocumentCode import DocumentCode
 from ampel.log.AmpelLogger import AmpelLogger
 from ampel.metrics.AmpelMetricsRegistry import AmpelMetricsRegistry
-from ampel.secret.NamedSecret import NamedSecret
 from ampel.protocol.LoggerProtocol import LoggerProtocol
-from ampel.enum.DocumentCode import DocumentCode
+from ampel.secret.NamedSecret import NamedSecret
 from ampel.types import Traceless
 from ampel.util.collections import ampel_iter
 from ampel.util.mappings import flatten_dict
@@ -32,8 +41,8 @@ from ampel.util.mappings import flatten_dict
 if TYPE_CHECKING:
     from ampel.config.AmpelConfig import AmpelConfig
     from ampel.content.DataPoint import DataPoint
-    from ampel.view.TransientView import TransientView
     from ampel.view.T2DocView import T2DocView
+    from ampel.view.TransientView import TransientView
 
 
 stat_http_errors = AmpelMetricsRegistry.counter(
@@ -67,12 +76,11 @@ stat_concurrent_requests = AmpelMetricsRegistry.gauge(
 def sanitize_json(obj):
     if isinstance(obj, dict):
         return {k: sanitize_json(v) for k, v in obj.items()}
-    elif isinstance(obj, (tuple, list)):
+    if isinstance(obj, tuple | list):
         return [sanitize_json(v) for v in obj]
-    elif isinstance(obj, float) and math.isnan(obj):
+    if isinstance(obj, float) and math.isnan(obj):
         return None
-    else:
-        return obj
+    return obj
 
 
 def encode_t2_body(t2: "T2DocView") -> str:
@@ -82,7 +90,9 @@ def encode_t2_body(t2: "T2DocView") -> str:
     return base64.b64encode(
         json.dumps(
             {
-                "timestamp": datetime.fromtimestamp(t2.meta[-1]["ts"]).isoformat(),
+                "timestamp": datetime.fromtimestamp(
+                    t2.meta[-1]["ts"], tz=timezone.utc
+                ).isoformat(),
                 **{k: sanitize_json(v) for k, v in doc.items() if k != "ts"},
             },
             default=lambda o: None,
@@ -103,23 +113,21 @@ def get_t2_result(
     t2: "T2DocView",
 ) -> tuple[None, None] | tuple[datetime, dict[str, Any]]:
     assert t2.body is not None
-    for meta, record in zip(reversed(t2.meta), reversed(t2.body)):
+    for meta, record in zip(reversed(t2.meta), reversed(t2.body), strict=False):  # noqa: B007
         if meta.get("code", DocumentCode.OK) == DocumentCode.OK:
             break
     else:
         return None, None
     assert isinstance(record, dict)
-    return datetime.fromtimestamp(meta["ts"]), record
+    return datetime.fromtimestamp(meta["ts"], tz=timezone.utc), record
 
 
 def render_thumbnail(cutout_data: bytes) -> str:
     """
     Render gzipped FITS as base64-encoded PNG
     """
-    with gzip.open(io.BytesIO(cutout_data), "rb") as f:
-        with fits.open(f) as hdu:
-            # header = hdu[0].header
-            img = np.flipud(hdu[0].data)
+    with gzip.open(io.BytesIO(cutout_data), "rb") as f, fits.open(f) as hdu:
+        img = np.flipud(hdu[0].data)
     mask = np.isfinite(img)
 
     fig = Figure(figsize=(1, 1))
@@ -139,7 +147,17 @@ def render_thumbnail(cutout_data: bytes) -> str:
 
 
 ZTF_FILTERS = {1: "ztfg", 2: "ztfr", 3: "ztfi"}
-CUTOUT_TYPES = {"science": "new", "template": "ref", "difference": "sub"}
+
+
+class CutoutSpec(AmpelBaseModel):
+    #: where to find cutouts
+    key: str = "ZTFCutoutImages"
+    #: mapping from cutout names to SkyPortal thumbnail types
+    types: dict[str, str] = {
+        "cutoutScience": "new",
+        "cutoutTemplate": "ref",
+        "cutoutDifference": "sub",
+    }
 
 
 class SkyPortalAPIError(IOError):
@@ -147,7 +165,6 @@ class SkyPortalAPIError(IOError):
 
 
 class SkyPortalClient(AmpelUnit):
-
     #: Base URL of SkyPortal server
     base_url: str
     #: API token
@@ -236,17 +253,17 @@ class SkyPortalClient(AmpelUnit):
             url = self.base_url + "/api/" + endpoint
         labels = (verb, endpoint.split("/")[0])
         async with self._semaphore:
-            with stat_http_time.labels(*labels).time(), stat_http_errors.labels(
-                *labels
-            ).count_exceptions(
-                ( # type: ignore[arg-type]
-                    aiohttp.ClientResponseError,
-                    aiohttp.ClientConnectionError,
-                    asyncio.TimeoutError,
-                )
-            ), stat_concurrent_requests.labels(
-                *labels
-            ).track_inprogress():
+            with (
+                stat_http_time.labels(*labels).time(),
+                stat_http_errors.labels(*labels).count_exceptions(
+                    (  # type: ignore[arg-type]
+                        aiohttp.ClientResponseError,
+                        aiohttp.ClientConnectionError,
+                        asyncio.TimeoutError,
+                    )
+                ),
+                stat_concurrent_requests.labels(*labels).track_inprogress(),
+            ):
                 async with self._session.request(
                     verb, url, **{**self._request_kwargs, **kwargs}
                 ) as response:
@@ -263,11 +280,9 @@ class SkyPortalClient(AmpelUnit):
                             ):
                                 raise SkyPortalAPIError(payload["message"], url, kwargs)
                             # otherwise, believe status code
-                            else:
-                                response.raise_for_status()
+                            response.raise_for_status()
                         return payload
-                    else:
-                        return response
+                    return response
 
     async def get_id(self, endpoint, params, default=None):
         """Query for an object by id, inserting it if not found"""
@@ -277,8 +292,7 @@ class SkyPortalClient(AmpelUnit):
             response = await self.post(endpoint, json=default or params)
         if isinstance(response["data"], list):
             return response["data"][0]["id"]
-        else:
-            return response["data"]["id"]
+        return response["data"]["id"]
 
     async def get_by_name(self, endpoint, name):
         if endpoint not in self._ids:
@@ -394,7 +408,7 @@ async def provision_seed_data(client: SkyPortalClient):
         "stream": await client.get_id("streams", {"name": "ztf_partnership"}),
         "group": 1,  # root group
     }
-    if not source["stream"] in [
+    if source["stream"] not in [
         groupstream["id"]
         for groupstream in (await client.get(f"groups/{source['group']}"))["data"][
             "streams"
@@ -419,7 +433,7 @@ async def provision_seed_data(client: SkyPortalClient):
         for users in (await client.get(f"groups/{source['group']}"))["data"]["users"]
     ]
     for user in (await client.get("user"))["data"]:
-        if not user["username"] in users:
+        if user["username"] not in users:
             await client.post(
                 f"groups/{source['group']}/users",
                 json={"username": user["username"]},
@@ -441,7 +455,6 @@ class PostReport(TypedDict):
 
 
 class BaseSkyPortalPublisher(SkyPortalClient):
-
     logger: Traceless[LoggerProtocol]
 
     def __init__(self, **kwargs):
@@ -485,11 +498,9 @@ class BaseSkyPortalPublisher(SkyPortalClient):
         return dict(content)
 
     async def _find_instrument(self, tags: Sequence[int | str]) -> int:
-        for tag in tags:
-            try:
+        with suppress(KeyError, aiohttp.ClientError):
+            for tag in tags:
                 return await self.get_by_name("instrument", tag)
-            except Exception:
-                ...
         raise KeyError(f"None of {tags} match a known instrument")
 
     async def post_t2_annotations(
@@ -601,10 +612,12 @@ class BaseSkyPortalPublisher(SkyPortalClient):
     async def post_candidate(
         self,
         view: "TransientView",
+        *,
         filters: None | list[str] = None,
         groups: None | list[str] = None,
         instrument: None | str = None,
         post_photometry: bool = True,
+        post_cutouts: None | CutoutSpec = None,
         annotate: bool = False,
     ) -> PostReport:
         """
@@ -652,6 +665,9 @@ class BaseSkyPortalPublisher(SkyPortalClient):
             )
         }
         group_ids = {await self.get_by_name("groups", name) for name in (groups or [])}
+        assert (
+            "tag" in view.stock
+        ), f"{self.__class__} requires stocks with a `tag` field. Did you remember to set AlertConsumer.compiler_opts?"
         assert view.stock["tag"] is not None
         instrument_id = (
             await self.get_by_name("instrument", instrument)
@@ -659,7 +675,11 @@ class BaseSkyPortalPublisher(SkyPortalClient):
             else await self._find_instrument(view.stock["tag"])
         )
 
-        assert view.stock and view.stock["name"] is not None
+        assert view.stock
+        assert (
+            "name" in view.stock
+        ), f"{self.__class__} requires stocks with a `name` field. Did you remember to set AlertConsumer.compiler_opts?"
+        assert view.stock["name"] is not None
         name = next(
             n for n in view.stock["name"] if isinstance(n, str) and n.startswith("ZTF")
         )
@@ -693,7 +713,9 @@ class BaseSkyPortalPublisher(SkyPortalClient):
 
         if (
             response := await self.get(
-                f"candidates/{name}", params={"includeComments": 1, "includeAlerts": 1}, raise_exc=False
+                f"candidates/{name}",
+                params={"includeComments": 1, "includeAlerts": 1},
+                raise_exc=False,
             )
         )["status"] == "success":
             # Only update filters, not the candidate itself
@@ -732,8 +754,10 @@ class BaseSkyPortalPublisher(SkyPortalClient):
                     json={
                         "id": name,
                         "filter_ids": fids,
-                        "passing_alert_id": jentry["alert"], # type: ignore[typeddict-item]
-                        "passed_at": datetime.fromtimestamp(jentry["ts"]).isoformat(),
+                        "passing_alert_id": jentry["alert"],  # type: ignore[typeddict-item]
+                        "passed_at": datetime.fromtimestamp(
+                            jentry["ts"], tz=timezone.utc
+                        ).isoformat(),
                         **candidate,
                     },
                 )
@@ -778,31 +802,32 @@ class BaseSkyPortalPublisher(SkyPortalClient):
             except SkyPortalAPIError as exc:
                 ret["photometry_error"] = exc.args[0]
 
-        # SkyPortal only supports one of thumbnail per object and type
-        # ('new', 'ref', 'sub', 'sdss', 'dr8', 'new_gz', 'ref_gz', 'sub_gz')
-        # Post one of each type only if they do not yet exist.
-        existing_cutouts: set[str] = (
-            {t["type"] for t in response["data"]["thumbnails"]}
-            if response["status"] == "success"
-            else set()
-        )
-        for candid, cutouts in (view.extra or {}).get("ZTFCutoutImages", {}).items():
-            for kind, blob in (cutouts or {}).items():
-                if CUTOUT_TYPES[kind] in existing_cutouts:
-                    continue
-                assert isinstance(blob, bytes)
-                # FIXME: switch back to FITS when SkyPortal supports it
-                await self.post(
-                    "thumbnail",
-                    json={
-                        "obj_id": name,
-                        "data": render_thumbnail(blob),
-                        "ttype": CUTOUT_TYPES[kind],
-                    },
-                    raise_exc=True,
-                )
-                existing_cutouts.add(CUTOUT_TYPES[kind])
-                ret["thumbnail_count"] += 1
+        if post_cutouts is not None:
+            # SkyPortal only supports one of thumbnail per object and type
+            # ('new', 'ref', 'sub', 'sdss', 'dr8', 'new_gz', 'ref_gz', 'sub_gz')
+            # Post one of each type only if they do not yet exist.
+            existing_cutouts: set[str] = (
+                {t["type"] for t in response["data"]["thumbnails"]}
+                if response["status"] == "success"
+                else set()
+            )
+            for cutouts in (view.extra or {}).get(post_cutouts.key, {}).values():
+                for kind, blob in (cutouts or {}).items():
+                    if post_cutouts.types[kind] in existing_cutouts:
+                        continue
+                    assert isinstance(blob, bytes)
+                    # FIXME: switch back to FITS when SkyPortal supports it
+                    await self.post(
+                        "thumbnail",
+                        json={
+                            "obj_id": name,
+                            "data": render_thumbnail(blob),
+                            "ttype": post_cutouts.types[kind],
+                        },
+                        raise_exc=True,
+                    )
+                    existing_cutouts.add(post_cutouts.types[kind])
+                    ret["thumbnail_count"] += 1
 
         # represent latest T2 results as a comments
         latest_t2: dict[str, "T2DocView"] = {}
